<?php
session_start();
require_once 'config/config.php';
require_once BASE_PATH.'/includes/auth_validate.php';


// Serve POST method, After successful insert, redirect to customers.php page.
if ($_SERVER['REQUEST_METHOD'] === 'POST') 
{
    // Mass Insert Data. Keep "name" attribute in html form same as column name in mysql table.
    $data_to_db = array_filter($_POST);

    // Insert user and timestamp
    //$data_to_db['created_by'] = $_SESSION['user_id'];
    $data_to_db['c_date'] = date('Y-m-d H:i:s');

    $db = getDbInstance();
    $last_id = $db->insert('category', $data_to_db);

    if ($last_id)
    {
        $_SESSION['success'] = 'Category added successfully!';
        // Redirect to the listing page
        header('Location: category.php');
        // Important! Don't execute the rest put the exit/die.
    	exit();
    }
    else
    {
        echo 'Insert failed: ' . $db->getLastError();
        exit();
    }
}

// Per page limit for pagination
$pagelimit = 15;

// Get current page
$page = filter_input(INPUT_GET, 'page');
if (!$page) {
	$page = 1;
}
$db = getDbInstance();
$select = array('cid', 'c_name', 'c_description', 'c_date', 'c_update');
// Set pagination limit
$db->pageLimit = $pagelimit;

// Get result of the query
$rows = $db->arraybuilder()->paginate('category', $page, $select);
$total_pages = $db->totalPages;

// We are using same form for adding and editing. This is a create form so declare $edit = false.
$edit = false;
?>
<?php include BASE_PATH.'/includes/header.php'; ?>
<div id="page-wrapper">
    <div class="row">
        <div class="col-lg-12">
            <h2 class="page-header">Add Category</h2>
        </div>
    </div>
    <!-- Flash messages -->
    <?php include BASE_PATH.'/includes/flash_messages.php'; ?>
    <form class="form" action="" method="post" id="category" enctype="multipart/form-data">
		
	<fieldset>
		<div class="form-group">
        	<label for="c_name">Category Name</label>
	        <input name="c_name" value="<?php echo htmlspecialchars($edit ? $category['c_name'] : '', ENT_QUOTES, 'UTF-8'); ?>" placeholder="Category name" class="form-control"  type="text" id="c_name">
    	</div>
		<div class="form-group">
    	    <label for="c_description">Description *</label>
        	  <textarea name="c_description" placeholder="desription" class="form-control" id="c_description" required="required"><?php echo htmlspecialchars(($edit) ? $category['c_description'] : '', ENT_QUOTES, 'UTF-8'); ?></textarea>
	    </div>
        
		<div class="form-group text-center">
    	    <label></label>
        	<button type="submit" class="btn btn-warning" >Save <i class="glyphicon glyphicon-send"></i></button>
	    </div>
</fieldset>
    </form>
	<hr/>
	
	<table class="table table-striped table-bordered table-condensed">
        <thead>
            <tr>
                <th width="5%">ID</th>
                <th width="20%">Name</th>
                <th width="20%">Description</th>
                <th width="20%">Created on</th>
				<th width="20%">Updated on</th>
                <th width="10%">Actions</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($rows as $row): ?>
            <tr>
                <td><?php echo $row['cid']; ?></td>
                <td><?php echo htmlspecialchars($row['c_name']); ?></td>
                <td><?php echo htmlspecialchars($row['c_description']); ?></td>
                <td><?php echo htmlspecialchars($row['c_date']); ?></td>
				<td><?php echo htmlspecialchars($row['c_update']); ?></td>
                <td>
                    <a href="edit_category.php?cat_id=<?php echo $row['cid']; ?>&operation=edit" class="btn btn-primary"><i class="glyphicon glyphicon-edit"></i></a>
                    <a href="#" class="btn btn-danger delete_btn" data-toggle="modal" data-target="#confirm-delete-<?php echo $row['cid']; ?>"><i class="glyphicon glyphicon-trash"></i></a>
                </td>
            </tr>
            <!-- Delete Confirmation Modal -->
            <div class="modal fade" id="confirm-delete-<?php echo $row['cid']; ?>" role="dialog">
                <div class="modal-dialog">
                    <form action="delete_category.php" method="POST">
                        <!-- Modal content -->
                        <div class="modal-content">
                            <div class="modal-header">
                                <button type="button" class="close" data-dismiss="modal">&times;</button>
                                <h4 class="modal-title">Confirm</h4>
                            </div>
                            <div class="modal-body">
                                <input type="hidden" name="del_id" id="del_id" value="<?php echo $row['cid']; ?>">
                                <p>Are you sure you want to delete this row?</p>
                            </div>
                            <div class="modal-footer">
                                <button type="submit" class="btn btn-default pull-left">Yes</button>
                                <button type="button" class="btn btn-default" data-dismiss="modal">No</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
            <!-- //Delete Confirmation Modal -->
            <?php endforeach; ?>
        </tbody>
    </table>
    <!-- //Table -->
	<!-- Pagination -->
    <div class="text-center">
    	<?php echo paginationLinks($page, $total_pages, 'category.php'); ?>
    </div>
    <!-- //Pagination -->
</div>

<script type="text/javascript">
$(document).ready(function(){
   $('#customer_form').validate({
       rules: {
            f_name: {
                required: true,
                minlength: 3
            },
            l_name: {
                required: true,
                minlength: 3
            },   
        }
    });
});
</script>
<?php include BASE_PATH.'/includes/footer.php'; ?>
